==> spread-5.4.1.16-py3-none-any.whl: spread_core/equipment_lighting.py <==
import logging

import spread_core.bam
import spread_core.mqtt as mqtt
from spread_core.errors.project_errors import EngineryError
from spread_core.tools.service_launcher import Launcher


class LightingEquipmentLauncher(Launcher):

    @property
    def manager(self):
        if self._manager is None:
            self._manager = spread_core.bam.equipment.LightingEquipment(self.project_id, self.mqttc)
        return self._manager

    def on_message(self, mosq, obj, msg):
        super(LightingEquipmentLauncher, self).on_message(mosq, obj, msg)
        topic = mqtt.of(msg.topic)
        try:
            payload = msg.payload.decode()
            if isinstance(topic, mqtt.spread.topic.SpreadTopic):
                var = mqtt.spread.variable.Variable.of(payload)
                if isinstance(topic, (mqtt.spread.topic.Set, mqtt.spread.topic.Renew)):
                    self._manager.on_command(topic, var)
                elif isinstance(topic, mqtt.spread.topic.State):
                    if topic.entity_address.funit_type in self._manager.EVENT_TOPICS:
                        self._manager.on_event(topic, var)
                    else:
                        self._manager.on_state(topic, var)
            elif isinstance(topic, mqtt.project.TopicProject):
                self._manager.on_project(topic, payload)
            elif isinstance(topic, mqtt.local.LAButtonPresets):
                self._manager.on_local(topic, payload)
            else:
                logging.debug('[{}] => {}'.format(msg.topic, payload))
        except EngineryError as ex:
            logging.warning(ex)
        except BaseException as ex:
            logging.exception(ex)


def run():
    LightingEquipmentLauncher().connect()


if __name__ == '__main__':
    run()

==> spread-5.9.0.59-py3-none-any.whl: spread_core/equipment_lighting.py <==
import logging

import spread_core.mqtt as mqtt
from spread_core.bam.equipment import LightingEquipment
from spread_core.errors.project_errors import EngineryError
from spread_core.tools.service_launcher import Launcher


class LightingEquipmentLauncher(Launcher):

    @property
    def manager(self):
        if self._manager is None:
            self._manager = LightingEquipment(self.project_id, self.mqttc)
        return self._manager

    def on_message(self, mosq, obj, msg):
        super(LightingEquipmentLauncher, self).on_message(mosq, obj, msg)
        topic = mqtt.topic_of(msg.topic)
        try:
            payload = msg.payload.decode()
            if isinstance(topic, mqtt.spread.topic.SpreadTopic):
                var = mqtt.spread.variable.Variable.of(payload)
                if isinstance(topic, (mqtt.spread.topic.Set, mqtt.spread.topic.Renew)):
                    self._manager.on_command(topic, var)
                elif isinstance(topic, mqtt.spread.topic.State):
                    self._manager.on_state(topic, var)
            elif isinstance(topic, mqtt.project.ProjectFile):
                self._manager.on_project(topic, payload)
            elif isinstance(topic, mqtt.project.Preset):
                self._manager.on_local(topic, payload)
            else:
                logging.debug('[{}] => {}'.format(msg.topic, payload))
        except EngineryError as ex:
            logging.warning(ex)
        except BaseException as ex:
            logging.exception(ex)


def run():
    LightingEquipmentLauncher().connect()


if __name__ == '__main__':
    run()
